@@ -1,12 +1,7 @@
-from __future__ import print_function
 import time
-import sys
+import Pyro5.api
+import Pyro5.errors
 
-import Pyro4
-
-
-if sys.version_info < (3, 0):
-    input = raw_input
 
 print("Autoreconnect using PYRO uri.")
 
@@ -14,7 +9,7 @@ print("Autoreconnect using PYRO uri.")
 # Reconnect logic depends on the server now.
 # (it needs to restart the object with the same id)
 uri = input("Enter the uri that the server printed:").strip()
-obj = Pyro4.core.Proxy(uri)
+obj = Pyro5.api.Proxy(uri)
 
 while True:
     print("call...")
@@ -22,7 +17,7 @@ while True:
         obj.method(42)
         print("Sleeping 1 second")
         time.sleep(1)
-    except Pyro4.errors.ConnectionClosedError:  # or possibly CommunicationError
+    except Pyro5.errors.ConnectionClosedError:  # or possibly CommunicationError
         print("Connection lost. REBINDING...")
         print("(restart the server now)")
         obj._pyroReconnect()
