@@ -1,18 +1,14 @@
-from __future__ import print_function
 from time import sleep
-import sys
-
-import Pyro4
-import Pyro4.errors
+import Pyro5.api
 
 
 # client side will not have timeout
-Pyro4.config.COMMTIMEOUT = 0
+Pyro5.config.COMMTIMEOUT = 0
 
 # Not using auto-retry feature
-Pyro4.config.MAX_RETRIES = 0
+Pyro5.config.MAX_RETRIES = 0
 
-obj = Pyro4.core.Proxy("PYRONAME:example.autoretry")
+obj = Pyro5.api.Proxy("PYRONAME:example.autoretry")
 print("Calling remote function 1st time (create connection)")
 obj.add(1, 1)
 print("Calling remote function 2nd time (not timed out yet)")
@@ -25,7 +21,7 @@ try:
 except Exception as e:
     print("Got exception %r as expected." % repr(e))
 
-print("Now, let's enable the auto retry")
+print("\nNow, let's enable the auto retry on the proxy")
 obj._pyroRelease()
 obj._pyroMaxRetries = 2
 
