@@ -2,13 +2,12 @@
 #   The banks server
 #
 
-from __future__ import print_function
-import Pyro4.core
-import Pyro4.naming
+from Pyro5.api import Daemon, locate_ns
 import banks
 
-with Pyro4.core.Daemon() as daemon:
-    with Pyro4.naming.locateNS() as ns:
+
+with Daemon() as daemon:
+    with locate_ns() as ns:
         uri = daemon.register(banks.Rabobank)
         ns.register("example.banks.rabobank", uri)
         uri = daemon.register(banks.ABN)
