@@ -1,16 +1,11 @@
-from __future__ import print_function
-import sys
 import time
-import Pyro4
-import bench
+from Pyro5.api import Proxy, config
 
-Pyro4.config.SERIALIZER = "marshal"
 
-if sys.version_info < (3, 0):
-    input = raw_input
+config.SERIALIZER = "marshal"
 
 uri = input("Uri of benchmark server? ").strip()
-obj = Pyro4.core.Proxy(uri)
+obj = Proxy(uri)
 obj._pyroBind()
 assert "oneway" in obj._pyroOneway   # make sure this method is indeed marked as @oneway
 
@@ -47,4 +42,5 @@ print('total time %.3f seconds' % duration)
 amount = len(funcs) * iters
 print('total method calls: %d' % amount)
 avg_pyro_msec = 1000.0 * duration / amount
-print('avg. time per method call: %.3f msec (%d/sec) (serializer: %s)' % (avg_pyro_msec, amount / duration, Pyro4.config.SERIALIZER))
+print('avg. time per method call: %.3f msec (%d/sec) (serializer: %s)'
+      % (avg_pyro_msec, amount / duration, config.SERIALIZER))
