@@ -1,17 +1,11 @@
-from __future__ import print_function
 import time
-import sys
+from Pyro5.api import Proxy, config
 
-import Pyro4
-
-
-if sys.version_info < (3, 0):
-    input = raw_input
 
 uri = input("Uri of benchmark server? ").strip()
 
 print("Timing raw connect speed (no method call)...")
-p = Pyro4.core.Proxy(uri)
+p = Proxy(uri)
 p.oneway()
 ITERATIONS = 2000
 begin = time.time()
@@ -30,13 +24,13 @@ begin = time.time()
 for loop in range(ITERATIONS):
     if loop % 500 == 0:
         print(loop)
-    with Pyro4.core.Proxy(uri) as p:
+    with Proxy(uri) as p:
         p.oneway()
 duration = time.time() - begin
 print("%d new proxy calls in %.3f sec = %.0f calls/sec" % (ITERATIONS, duration, ITERATIONS / duration))
 
-print("Timing proxy methodcall speed...")
-p = Pyro4.core.Proxy(uri)
+print("Timing oneway proxy methodcall speed...")
+p = Proxy(uri)
 p.oneway()
 ITERATIONS = 10000
 begin = time.time()
@@ -46,4 +40,4 @@ for loop in range(ITERATIONS):
     p.oneway()
 duration = time.time() - begin
 print("%d calls in %.3f sec = %.0f calls/sec" % (ITERATIONS, duration, ITERATIONS / duration))
-print("Serializer used:", Pyro4.config.SERIALIZER)
+print("Serializer used:", config.SERIALIZER)
