@@ -1,6 +1,5 @@
-from __future__ import print_function
 import sys
-import Pyro4
+from Pyro5.api import Daemon
 from listener import Listener
 
 
@@ -11,7 +10,7 @@ else:
     if not topic:
         raise ValueError("Must give topic name.")
     listener = Listener(topic)
-    daemon = Pyro4.Daemon()
+    daemon = Daemon()
     daemon.register(listener)
     listener.register_with_dispatcher()
     print("Listener for topic {} waiting for data.".format(topic))
