@@ -1,10 +1,11 @@
-import Pyro4
+from Pyro5.api import expose, behavior, serve
+import Pyro5.errors
 
 
 # Chat box administration server.
 # Handles logins, logouts, channels and nicknames, and the chatting.
-@Pyro4.expose
-@Pyro4.behavior(instance_mode="single")
+@expose
+@behavior(instance_mode="single")
 class ChatBox(object):
     def __init__(self):
         self.channels = {}  # registered channels { channel --> (nick, client callback) list }
@@ -50,9 +51,10 @@ class ChatBox(object):
             print('IGNORED UNKNOWN CHANNEL %s' % channel)
             return
         for (n, c) in self.channels[channel][:]:  # use a copy of the list
+            c._pyroClaimOwnership()
             try:
                 c.message(nick, msg)  # oneway call
-            except Pyro4.errors.ConnectionClosedError:
+            except Pyro5.errors.ConnectionClosedError:
                 # connection dropped, remove the listener if it's still there
                 # check for existence because other thread may have killed it already
                 if (n, c) in self.channels[channel]:
@@ -60,6 +62,6 @@ class ChatBox(object):
                     print('Removed dead listener %s %s' % (n, c))
 
 
-Pyro4.Daemon.serveSimple({
+serve({
     ChatBox: "example.chatbox.server"
 })
