@@ -1,5 +1,4 @@
-from __future__ import print_function
-import Pyro4
+from Pyro5.api import expose, Proxy
 
 
 # a Chain member. Passes messages to the next link,
@@ -11,10 +10,10 @@ class Chain(object):
         self.nextName = next_node
         self.next = None
 
-    @Pyro4.expose
+    @expose
     def process(self, message):
         if self.next is None:
-            self.next = Pyro4.core.Proxy("PYRONAME:example.chain." + self.nextName)
+            self.next = Proxy("PYRONAME:example.chain." + self.nextName)
         if self.name in message:
             print("Back at %s; we completed the circle!" % self.name)
             return ["complete at " + self.name]
