@@ -1,22 +1,17 @@
-from __future__ import print_function
-import sys
 import warnings
-
-import Pyro4
-import Pyro4.message
+import Pyro5.api
+import Pyro5.protocol
+import Pyro5.errors
 
 
 warnings.filterwarnings("ignore")
 
-if sys.version_info < (3, 0):
-    input = raw_input
-
 print("You can run this client on a different computer so you can disable the network connection (by yanking out the lan cable or whatever).")
 print("Alternatively, wait for a timeout on the server, which will then close its connection.")
 uri = input("Uri of server? ").strip()
 
 
-class AutoReconnectingProxy(Pyro4.core.Proxy):
+class AutoReconnectingProxy(Pyro5.api.Proxy):
     """
     A Pyro proxy that automatically recovers from a server disconnect.
     It does this by intercepting every method call and then it first 'pings'
@@ -35,9 +30,9 @@ class AutoReconnectingProxy(Pyro4.core.Proxy):
         if self._pyroConnection:
             try:
                 print("  <proxy: ping>")
-                Pyro4.message.Message.ping(self._pyroConnection, hmac_key=None)    # utility method on the Message class
+                Pyro5.protocol.SendingMessage.ping(self._pyroConnection)    # utility method on the Message class
                 print("  <proxy: ping reply (still connected)>")
-            except Pyro4.errors.ConnectionClosedError:
+            except Pyro5.errors.ConnectionClosedError:
                 print("  <proxy: Connection lost. REBINDING...>")
                 self._pyroReconnect()
                 print("  <proxy: Connection restored, continue with actual method call...>")
