@@ -1,18 +1,12 @@
-from __future__ import print_function
 import os
 import socket
-import sys
 from math import sqrt
-import Pyro4
-import Pyro4.socketutil
-
-
-if sys.version_info < (3, 0):
-    range = xrange   # make sure to use the memory efficient range generator
+from Pyro5.api import expose, Daemon, locate_ns
+import Pyro5.socketutil
 
 
 class Worker(object):
-    @Pyro4.expose
+    @expose
     def factorize(self, n):
         print("factorize request received for", n)
         result = self._factorize(n)
@@ -35,11 +29,11 @@ class Worker(object):
         return primes
 
 
-with Pyro4.Daemon(host=Pyro4.socketutil.getIpAddress(None)) as daemon:
+with Daemon(host=Pyro5.socketutil.get_ip_address(None)) as daemon:
     # create a unique name for this worker (otherwise it overwrites other workers in the name server)
     worker_name = "Worker_%d@%s" % (os.getpid(), socket.gethostname())
     print("Starting up worker", worker_name)
     uri = daemon.register(Worker)
-    with Pyro4.locateNS() as ns:
+    with locate_ns() as ns:
         ns.register(worker_name, uri, metadata={"example3.worker.factorizer"})
     daemon.requestLoop()
