@@ -2,7 +2,7 @@
 import time
 import tkinter
 from concurrent import futures
-from Pyro4 import Proxy, locateNS
+from Pyro5.api import Proxy, locate_ns
 
 
 res_x = 1000
@@ -17,13 +17,13 @@ class MandelWindow(object):
         canvas.pack()
         self.img = tkinter.PhotoImage(width=res_x, height=res_y)
         canvas.create_image((res_x/2, res_y/2), image=self.img, state="normal")
-        with locateNS() as ns:
-            mandels = ns.list(metadata_any={"class:mandelbrot_calc_color"})
+        with locate_ns() as ns:
+            mandels = ns.yplookup(meta_any={"class:mandelbrot_calc_color"})
             mandels = list(mandels.items())
         print("{0} mandelbrot calculation servers found.".format(len(mandels)))
         if not mandels:
             raise ValueError("launch at least one mandelbrot calculation server before starting this")
-        self.mandels = [uri for _, uri in mandels]
+        self.mandels = [uri for _, (uri, meta) in mandels]
         self.pool = futures.ThreadPoolExecutor(max_workers=len(self.mandels))
         self.tasks = []
         self.start_time = time.time()
