@@ -1,13 +1,9 @@
 # mandelbrot fractal,  z=z^2+c
-from __future__ import print_function, division
 import time
-try:
-    import tkinter
-except ImportError:
-    import Tkinter as tkinter
-
+import tkinter
 from server import MandelbrotColorPixels
 
+
 res_x = 1000
 res_y = 800
 
@@ -15,7 +11,7 @@ res_y = 800
 class MandelWindow(object):
     def __init__(self):
         self.root = tkinter.Tk()
-        self.root.title("Mandelbrot (Single Core)")
+        self.root.title("Mandelbrot (Single CPU core)")
         canvas = tkinter.Canvas(self.root, width=res_x, height=res_y, bg="#000000")
         canvas.pack()
         self.img = tkinter.PhotoImage(width=res_x, height=res_y)
