@@ -1,14 +1,10 @@
-from __future__ import print_function
 import time
 import threading
-import sys
 import socket
 import zlib
-import Pyro4
+import sys
 import serpent
-
-if sys.version_info < (3, 0):
-    input = raw_input
+from Pyro5.api import Proxy, current_context
 
 
 def regular_pyro(uri):
@@ -16,8 +12,8 @@ def regular_pyro(uri):
     num_blobs = 10
     total_size = 0
     start = time.time()
-    name = threading.currentThread().name
-    with Pyro4.core.Proxy(uri) as p:
+    name = threading.current_thread().name
+    with Proxy(uri) as p:
         for _ in range(num_blobs):
             print("thread {0} getting a blob using regular Pyro call...".format(name))
             data = p.get_with_pyro(blobsize)
@@ -33,8 +29,8 @@ def via_iterator(uri):
     num_blobs = 10
     total_size = 0
     start = time.time()
-    name = threading.currentThread().name
-    with Pyro4.core.Proxy(uri) as p:
+    name = threading.current_thread().name
+    with Proxy(uri) as p:
         for _ in range(num_blobs):
             print("thread {0} getting a blob using remote iterators...".format(name))
             for chunk in p.iterator(blobsize):
@@ -46,19 +42,19 @@ def via_iterator(uri):
 
 
 def via_annotation_stream(uri):
-    name = threading.currentThread().name
+    name = threading.current_thread().name
     start = time.time()
     total_size = 0
     print("thread {0} downloading via annotation stream...".format(name))
-    with Pyro4.core.Proxy(uri) as p:
+    with Proxy(uri) as p:
         perform_checksum = False
         for progress, checksum in p.annotation_stream(perform_checksum):
-            chunk = Pyro4.current_context.response_annotations["FDAT"]
+            chunk = current_context.response_annotations["FDAT"]
             if perform_checksum and zlib.crc32(chunk) != checksum:
                 raise ValueError("checksum error")
             total_size += len(chunk)
             assert progress == total_size
-            Pyro4.current_context.response_annotations.clear()  # clean them up once we're done with them
+            current_context.response_annotations.clear()  # clean them up once we're done with them
     duration = time.time() - start
     print("thread {0} done, {1:.2f} Mb/sec.".format(name, total_size/1024.0/1024.0/duration))
 
@@ -67,8 +63,8 @@ def raw_socket(uri):
     blobsize = 40*1024*1024
     num_blobs = 10
     total_size = 0
-    name = threading.currentThread().name
-    with Pyro4.core.Proxy(uri) as p:
+    name = threading.current_thread().name
+    with Proxy(uri) as p:
         print("thread {0} preparing {1} blobs of size {2} Mb".format(name, num_blobs, blobsize/1024.0/1024.0))
         blobs = {}
         for _ in range(num_blobs):
@@ -83,7 +79,7 @@ def raw_socket(uri):
             sock.connect(tuple(blob_address))
             sock.sendall(file_id.encode())
             size = 0
-            chunk = "dummy"
+            chunk = b"dummy"
             while chunk:
                 chunk = sock.recv(60000)
                 size += len(chunk)
