@@ -1,22 +1,17 @@
-from __future__ import print_function
-
-import Pyro4
-import Pyro4.socketutil
 import serpent
-
-
-# Pyro4.config.COMMTIMEOUT=2
+from Pyro5.api import expose, serve, config
+import Pyro5.socketutil
 
 
 class Testclass(object):
-    @Pyro4.expose
+    @expose
     def transfer(self, data):
-        if Pyro4.config.SERIALIZER == "serpent" and type(data) is dict:
+        if config.SERIALIZER == "serpent" and type(data) is dict:
             data = serpent.tobytes(data)  # in case of serpent encoded bytes
         print("received %d bytes" % len(data))
         return len(data)
 
-    @Pyro4.expose
+    @expose
     def download_chunks(self, size):
         print("client requests a 'streaming' download of %d bytes" % size)
         data = bytearray(size)
@@ -28,9 +23,9 @@ class Testclass(object):
             i += chunksize
 
 
-Pyro4.Daemon.serveSimple(
+serve(
     {
         Testclass: "example.hugetransfer"
     },
-    host=Pyro4.socketutil.getIpAddress("localhost", workaround127=True),
-    ns=False, verbose=True)
+    host=Pyro5.socketutil.get_ip_address("localhost", workaround127=True),
+    use_ns=False, verbose=True)
