@@ -1,10 +1,10 @@
-from __future__ import print_function
 import sys
 import random
 import time
 import threading
-import Pyro4.errors
-import Pyro4.naming
+import contextlib
+from Pyro5.api import Proxy, locate_ns
+import Pyro5.errors
 
 
 def randomname():
@@ -22,7 +22,7 @@ class NamingTrasher(threading.Thread):
         threading.Thread.__init__(self)
         self.daemon = True
         self.number = number
-        self.ns = Pyro4.core.Proxy(nsuri)
+        self.ns = Proxy(nsuri)
         self.mustStop = False
 
     def list(self):
@@ -30,19 +30,15 @@ class NamingTrasher(threading.Thread):
 
     def register(self):
         for i in range(4):
-            try:
+            with contextlib.suppress(Pyro5.errors.NamingError):
                 self.ns.register(randomname(), 'PYRO:objname@host:555')
-            except Pyro4.errors.NamingError:
-                pass
 
     def remove(self):
         self.ns.remove(randomname())
 
     def lookup(self):
-        try:
+        with contextlib.suppress(Pyro5.errors.NamingError):
             uri = self.ns.lookup(randomname())
-        except Pyro4.errors.NamingError:
-            pass
 
     def listprefix(self):
         entries = self.ns.list(prefix="stresstest.51")
@@ -52,6 +48,7 @@ class NamingTrasher(threading.Thread):
 
     def run(self):
         print("Name Server trasher running.")
+        self.ns._pyroClaimOwnership()
         while not self.mustStop:
             random.choice((self.list, self.register, self.remove, self.lookup, self.listregex, self.listprefix))()
             sys.stdout.write("%d " % self.number)
@@ -62,7 +59,7 @@ class NamingTrasher(threading.Thread):
 
 def main():
     threads = []
-    ns = Pyro4.naming.locateNS()
+    ns = locate_ns()
     print("Removing previous stresstest registrations...")
     ns.remove(prefix="stresstest.")
     print("Done. Starting.")
