@@ -1,17 +1,12 @@
 import random
 import time
 import threading
-
+from tkinter import *
+import Pyro5.errors
+import Pyro5.api
 import robot
 import remote
 
-try:
-    from tkinter import *
-except ImportError:
-    from Tkinter import *
-import Pyro4
-import Pyro4.util
-
 
 class VisibleRobot(robot.Robot):
     """represents a robot that is visible on the screen."""
@@ -114,8 +109,12 @@ class GameEngine(object):
         self.gui.statuslabel.config(text="new round!")
         print("WORLD:")
         for line in self.world.dump():
-            print(line.tostring())
+            print("|", line.decode(), "|")
         print("NUMBER OF ROBOTS: %d" % len(self.world.robots))
+        # make sure the observers of all robots are owned by this thread (if they're a Pyro proxy)
+        for robot in self.world.robots:
+            if isinstance(robot.observer, Pyro5.api.Proxy):
+                robot.observer._pyroClaimOwnership()
         txtid = self.grid.create_text(20, 20, text="GO!", font=("Courier", 120, "bold"), anchor=NW, fill='purple')
         self.grid.after(1500, lambda: self.grid.delete(txtid))
         self.grid.after(2000, self.update)
@@ -178,8 +177,8 @@ class GameEngine(object):
     def signup_robot(self, name, observer=None):
         if not self.open_for_signups:
             raise RuntimeError("signups are closed, try again later")
-        for r in self.world.robots:
-            if r.name == name:
+        for robot in self.world.robots:
+            if robot.name == name:
                 raise ValueError("that name is already taken")
         colorint = random.randint(0, 0xFFFFFF)
         color = '#%06x' % colorint
@@ -191,11 +190,11 @@ class GameEngine(object):
             y = random.randint(int(self.grid.height * 0), self.grid.height - 1)
             if not self.world.collides(x, y):
                 break
-        r = VisibleRobot(name, (x, y), (0, 0), self.grid, color=color)
-        self.world.add_robot(r)
-        r.observer = observer
-        r.popuptext(name)
-        return remote.RemoteBot(r, self)
+        robot = VisibleRobot(name, (x, y), (0, 0), self.grid, color=color)
+        self.world.add_robot(robot)
+        robot.observer = observer
+        robot.popuptext(name)
+        return remote.RemoteBot(robot, self)
 
     def remove_robot(self, robot):
         robot.delete_from_grid()
@@ -241,21 +240,21 @@ class PyroDaemonThread(threading.Thread):
     def __init__(self, engine):
         threading.Thread.__init__(self)
         self.pyroserver = remote.GameServer(engine)
-        self.pyrodaemon = Pyro4.Daemon()
-        self.ns = Pyro4.locateNS()
-        self.setDaemon(True)
+        self.pyrodaemon = Pyro5.api.Daemon()
+        self.daemon = True
 
     def run(self):
+        ns = Pyro5.api.locate_ns()
         with self.pyrodaemon:
-            with self.ns:
+            with ns:
                 uri = self.pyrodaemon.register(self.pyroserver)
-                self.ns.register("example.robotserver", uri)
+                ns.register("example.robotserver", uri)
                 print("Pyro server registered on %s" % self.pyrodaemon.locationStr)
                 self.pyrodaemon.requestLoop()
 
 
 # register the Robot class with Pyro's serializers:
-Pyro4.util.SerializerBase.register_class_to_dict(VisibleRobot, robot.Robot.robot_to_dict)
+Pyro5.api.SerializerBase.register_class_to_dict(VisibleRobot, robot.Robot.robot_to_dict)
 
 
 def main():
@@ -266,7 +265,7 @@ def main():
     engine = GameEngine(gui, world)
     try:
         PyroDaemonThread(engine).start()
-    except Pyro4.errors.NamingError:
+    except Pyro5.errors.NamingError:
         print("Can't find the Pyro Nameserver. Running without remote connections.")
     gui.tk.mainloop()
 
