@@ -1,9 +1,8 @@
-from __future__ import print_function
 import random
-import Pyro4
+from Pyro5.api import expose, oneway
 
 
-@Pyro4.expose
+@expose
 class GameServer(object):
     def __init__(self, engine):
         self.engine = engine
@@ -14,7 +13,7 @@ class GameServer(object):
         return robot
 
 
-@Pyro4.expose
+@expose
 class RemoteBot(object):
     def __init__(self, robot, engine):
         self.robot = robot
@@ -33,13 +32,13 @@ class RemoteBot(object):
         self.engine.remove_robot(self.robot)
 
 
-@Pyro4.expose
+@expose
 class LocalGameObserver(object):
     def __init__(self, name):
         self.name = name
         self.robot = None
 
-    @Pyro4.oneway
+    @oneway
     def world_update(self, iteration, world, robotdata):
         # change directions randomly
         if random.random() > 0.8:
@@ -62,7 +61,7 @@ class LocalGameObserver(object):
             print("[%s] I DIED" % self.name)
 
 
-@Pyro4.expose
+@expose
 class GameObserver(object):
     def world_update(self, iteration, world, robotdata):
         pass
