@@ -1,8 +1,3 @@
-from __future__ import print_function
-import sys
-import array
-
-
 class Wall(object):
     """an obstructing static wall"""
 
@@ -115,10 +110,8 @@ class World(object):
         self.robots.remove(obj)
 
     def dump(self):
-        line = ' ' * self.width
-        if sys.version_info >= (3, 0):
-            line = bytes(line, "ASCII")
-        grid = [array.array('b', line) for y in range(self.height)]
+        line = b' ' * self.width
+        grid = [bytearray(line) for _ in range(self.height)]
         for obj in self.all:
             grid[obj.y][obj.x] = ord('R') if isinstance(obj, Robot) else ord('#')
         return grid
