@@ -1,19 +1,10 @@
-from __future__ import print_function
 import time
-import sys
 import threading
-import Pyro4
+from Pyro5.api import expose, behavior, oneway, serve, config
 
 
-if sys.version_info < (3, 0):
-    input = raw_input
-    current_thread = threading.currentThread
-else:
-    current_thread = threading.current_thread
-
-
-@Pyro4.expose
-@Pyro4.behavior(instance_mode="single")
+@expose
+@behavior(instance_mode="single")
 class Server(object):
     def __init__(self):
         self.callcount = 0
@@ -25,18 +16,18 @@ class Server(object):
         return self.callcount  # the number of completed calls
 
     def getconfig(self):
-        return Pyro4.config.asDict()
+        return config.as_dict()
 
     def delay(self):
-        threadname = current_thread().getName()
+        threadname = threading.current_thread().name
         print("delay called in thread %s" % threadname)
         time.sleep(1)
         self.callcount += 1
         return threadname
 
-    @Pyro4.oneway
+    @oneway
     def onewaydelay(self):
-        threadname = current_thread().getName()
+        threadname = threading.current_thread().name
         print("onewaydelay called in thread %s" % threadname)
         time.sleep(1)
         self.callcount += 1
@@ -44,14 +35,14 @@ class Server(object):
 
 # main program
 
-Pyro4.config.SERVERTYPE = "undefined"
+config.SERVERTYPE = "undefined"
 servertype = input("Servertype threaded or multiplex (t/m)?")
 if servertype == "t":
-    Pyro4.config.SERVERTYPE = "thread"
+    config.SERVERTYPE = "thread"
 else:
-    Pyro4.config.SERVERTYPE = "multiplex"
+    config.SERVERTYPE = "multiplex"
 
 
-Pyro4.Daemon.serveSimple({
+serve({
     Server: "example.servertypes"
 })
