@@ -1,8 +1,7 @@
-from __future__ import print_function
-import Pyro4
+from Pyro5.api import expose
 
 
-@Pyro4.expose
+@expose
 class ShoppingCart(object):
     def __init__(self):
         self.contents = []
