@@ -1,12 +1,10 @@
-from __future__ import print_function
 import time
-
-import Pyro4
+from Pyro5.api import expose, behavior, serve
 from shoppingcart import ShoppingCart
 
 
-@Pyro4.expose
-@Pyro4.behavior(instance_mode="single")
+@expose
+@behavior(instance_mode="single")
 class Shop(object):
     inventory = {
         "paper": 1.25,
@@ -75,6 +73,6 @@ class Shop(object):
 
 # main program
 
-Pyro4.Daemon.serveSimple({
+serve({
     Shop: "example.shop"
 })
