@@ -1,10 +1,9 @@
-from __future__ import print_function
 import random
 import time
-import Pyro4
+from Pyro5.api import expose, Daemon, locate_ns
 
 
-@Pyro4.expose
+@expose
 class StockMarket(object):
     def __init__(self, marketname, symbols):
         self._name = marketname
@@ -28,11 +27,11 @@ class StockMarket(object):
 if __name__ == "__main__":
     nasdaq = StockMarket("NASDAQ", ["AAPL", "CSCO", "MSFT", "GOOG"])
     newyork = StockMarket("NYSE", ["IBM", "HPQ", "BP"])
-    # for example purposes we will access the daemon and name server ourselves and not use serveSimple
-    with Pyro4.Daemon() as daemon:
+    # for example purposes we will access the daemon and name server ourselves
+    with Daemon() as daemon:
         nasdaq_uri = daemon.register(nasdaq)
         newyork_uri = daemon.register(newyork)
-        with Pyro4.locateNS() as ns:
+        with locate_ns() as ns:
             ns.register("example.stockmarket.nasdaq", nasdaq_uri)
             ns.register("example.stockmarket.newyork", newyork_uri)
         print("Stockmarkets available.")
