@@ -1,16 +1,13 @@
-from __future__ import print_function, division
 import sys
-import Pyro4
-import Pyro4.util
+import Pyro5.errors
+import Pyro5.api
 
-if sys.version_info < (3, 0):
-    input = raw_input
 
-sys.excepthook = Pyro4.util.excepthook
+sys.excepthook = Pyro5.errors.excepthook
 
 
 uri = input("Enter streaming server uri: ").strip()
-with Pyro4.Proxy(uri) as p:
+with Pyro5.api.Proxy(uri) as p:
     print("\nnormal list:")
     print(p.list())
     print("\nvia iterator:")
