@@ -1,15 +1,14 @@
-from __future__ import print_function, division
 import time
-import Pyro4
+from Pyro5.api import expose, serve, config
 
 
-if Pyro4.config.ITER_STREAMING:
+if config.ITER_STREAMING:
     print("Note: iter-streaming has been enabled in the Pyro config.")
 else:
     print("Note: iter-streaming has not been enabled in the Pyro config (PYRO_ITER_STREAMING).")
 
 
-@Pyro4.expose
+@expose
 class Streamer(object):
     def list(self):
         return [1, 2, 3, 4, 5, 6, 7, 8, 9]
@@ -37,6 +36,6 @@ class Streamer(object):
             a, b = b, a + b
 
 
-Pyro4.Daemon.serveSimple({
+serve({
         Streamer: "example.streamer"
-    }, ns=False)
+    }, use_ns=False)
