@@ -1,20 +1,14 @@
-from __future__ import print_function
-import sys
+from Pyro5.api import Proxy
+import Pyro5.errors
 
-import Pyro4
-import Pyro4.errors
-
-
-if sys.version_info < (3, 0):
-    input = raw_input
 
 uri = input("Enter the URI of the thirdparty library object: ").strip()
-with Pyro4.core.Proxy(uri) as remote:
+with Proxy(uri) as remote:
     print(remote.method("how are you?"))
 
     try:
         print(remote.weird())
-    except Pyro4.errors.SerializeError:
+    except Pyro5.errors.SerializeError:
         print("couldn't call weird() due to serialization error of the result value! (is ok)")
 
     try:
