@@ -1,9 +1,7 @@
-from __future__ import print_function
 import time
 import sys
-
-import Pyro4
-import Pyro4.errors
+import Pyro5.errors
+from Pyro5.api import Proxy
 
 
 # NOTE: the timer in IronPython seems to be wacky.
@@ -13,9 +11,9 @@ def approxEqual(x, y):
     return abs(x - y) < 0.2
 
 # disable timeout globally
-Pyro4.config.COMMTIMEOUT = 0
+Pyro5.config.COMMTIMEOUT = 0
 
-obj = Pyro4.core.Proxy("PYRONAME:example.timeout")
+obj = Proxy("PYRONAME:example.timeout")
 obj._pyroBind()
 print("No timeout is configured. Calling delay with 2 seconds.")
 start = time.time()
@@ -34,7 +32,7 @@ start = time.time()
 try:
     result = obj.delay(2)
     print("!?should have raised TimeoutError!?")
-except Pyro4.errors.TimeoutError:
+except Pyro5.errors.TimeoutError:
     print("TimeoutError! As expected!")
     duration = time.time() - start
     if sys.platform != "cli":
@@ -43,15 +41,15 @@ except Pyro4.errors.TimeoutError:
         assert 0.9 < duration < 1.9, "expected about 1 second duration"
 
 # set timeout globally
-Pyro4.config.COMMTIMEOUT = 1
+Pyro5.config.COMMTIMEOUT = 1
 
-obj = Pyro4.core.Proxy("PYRONAME:example.timeout")
+obj = Proxy("PYRONAME:example.timeout")
 print("COMMTIMEOUT is set globally. Calling delay with 2 seconds.")
 start = time.time()
 try:
     result = obj.delay(2)
     print("!?should have raised TimeoutError!?")
-except Pyro4.errors.TimeoutError:
+except Pyro5.errors.TimeoutError:
     print("TimeoutError! As expected!")
     duration = time.time() - start
     if sys.platform != "cli":
@@ -72,14 +70,14 @@ else:
     assert 2.5 < duration < 3.5, "expected about 3 second duration"
 
 print("Trying to connect to the frozen daemon.")
-obj = Pyro4.core.Proxy("PYRONAME:example.timeout.frozendaemon")
+obj = Proxy("PYRONAME:example.timeout.frozendaemon")
 obj._pyroTimeout = 1
 print("Timeout set to 1 seconds. Trying to connect.")
 start = time.time()
 try:
     result = obj.delay(5)
     print("!?should have raised TimeoutError!?")
-except Pyro4.errors.TimeoutError:
+except Pyro5.errors.TimeoutError:
     print("TimeoutError! As expected!")
     duration = time.time() - start
     if sys.platform != "cli":
