@@ -1,11 +1,8 @@
-from __future__ import print_function
 import time
-
-import Pyro4.naming
-import Pyro4.core
+from Pyro5.api import expose, locate_ns, Daemon, config
 
 
-@Pyro4.expose
+@expose
 class TimeoutServer(object):
     def delay(self, amount):
         print("sleeping %d" % amount)
@@ -14,11 +11,11 @@ class TimeoutServer(object):
         return "slept %d seconds" % amount
 
 
-Pyro4.config.COMMTIMEOUT = 0  # the server won't be using timeouts
+config.COMMTIMEOUT = 0  # the server won't be using timeouts
 
-ns = Pyro4.naming.locateNS()
-daemon = Pyro4.core.Daemon()
-daemon2 = Pyro4.core.Daemon()
+ns = locate_ns()
+daemon = Daemon()
+daemon2 = Daemon()
 obj = TimeoutServer()
 obj2 = TimeoutServer()
 uri = daemon.register(obj)
@@ -27,5 +24,5 @@ ns.register("example.timeout", uri)
 ns.register("example.timeout.frozendaemon", uri2)
 print("Server ready.")
 # Note that we're only starting one of the 2 daemons.
-# daemon2 is not started to simulate connection timeouts.
+# daemon2 is not started, to simulate connection timeouts.
 daemon.requestLoop()
