@@ -1,9 +1,8 @@
-from __future__ import print_function
-import Pyro4
+from Pyro5.api import expose, behavior, serve
 
 
-@Pyro4.expose
-@Pyro4.behavior(instance_mode="single")
+@expose
+@behavior(instance_mode="single")
 class Warehouse(object):
     def __init__(self):
         self.contents = ["chair", "bike", "flashlight", "laptop", "couch"]
@@ -20,13 +19,8 @@ class Warehouse(object):
         print("{0} stored the {1}.".format(name, item))
 
 
-def main():
-    Pyro4.Daemon.serveSimple(
-        {
-            Warehouse: "example.warehouse"
-        },
-        ns=True)
-
-
-if __name__ == "__main__":
-    main()
+serve(
+    {
+        Warehouse: "example.warehouse"
+    },
+    use_ns=True)
